==> resh-5.0.0.16-py3-none-any.whl: reface/dashboard/forms.py <==
from django import forms
from django.utils.safestring import mark_safe

from reface.dashboard import fields
from resh.domains import dali1, dali2
from resh.utils import const_values as v


class _LineUtils(forms.Form):
    DALI1 = 'dali'
    DALI2 = 'dali2'
    ALL = 'all'

    ACTION = 'action'
    START = 'start'
    STOP = 'stop'
    SCAN = 'scan'

    EXTEND = 'extend_line'
    CONSTRUCT = 'construct_line'
    DOUBLE_ADDRESSES = 'fix_double_addresses'

    VERBOSE_EXTEND = 'Расширение линии'
    VERBOSE_CONSTRUCT = 'Сбор линии'
    VERBOSE_DOUBLE_ADDRESSES = 'Разрешение задвоенных адресов'

    COMMANDS = {
        DALI1: {
            EXTEND: dali1.extend_line,
            CONSTRUCT: dali1.construct_line,
            DOUBLE_ADDRESSES: dali1.fix_double_addresses,
            SCAN: dali1.dump,
        },
        DALI2: {
            EXTEND: dali2.extend_line,
            CONSTRUCT: dali2.construct_line,
            DOUBLE_ADDRESSES: dali2.fix_double_addresses,
            SCAN: dali2.dump,
        }
    }

    DALI_TYPES = (('', ''), (DALI1, 'DALI 1'), (DALI2, 'DALI 2'))


class LineBuilder(_LineUtils):
    dali_type = forms.ChoiceField(choices=_LineUtils.DALI_TYPES, label='Тип устройств')
    cross = forms.BooleanField(label='Пересекающиеся адреса', initial=True, required=False)
    first_address = forms.IntegerField(initial=0, min_value=0, max_value=64, label='Начинать с адреса')

    @classmethod
    def verbose_name(cls, command_name):
        return {
            cls.EXTEND: cls.VERBOSE_EXTEND,
            cls.CONSTRUCT: cls.VERBOSE_CONSTRUCT,
            cls.DOUBLE_ADDRESSES: cls.VERBOSE_DOUBLE_ADDRESSES,
        }.get(command_name, 'Назначение адресов')

    @property
    def mode(self): return 'CROSS' if self.cleaned_data['cross'] else 'NOCROSS'

    def command(self, action): return self.COMMANDS[self.cleaned_data['dali_type']][action]

    @property
    def start_address(self): return self.cleaned_data.get('first_address', 0)


class LineScanner(_LineUtils):
    @classmethod
    def columns(cls):
        return {
            v.COMMON: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.GTIN, 'Gtin'),
                (v.SERIAL, 'Serial'),
                (v.GTIN_OEM, 'GtinOem'),
                (v.SERIAL_OEM, 'SerialOem'),
                (v.FIRMWARE, 'F.Ver'),
                (v.HARDWARE, 'H.Ver'),
                (v.GROUPS, 'Groups'),
                (v.OPERATING_MODE, 'Op.Mode'),
            )],
            v.DALI: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.FADE_TIME, 'FadeTime'),
                (v.FADE_RATE, 'FadeRate'),
                (v.DIMMING_CURVE, 'DimmingCurve'),
                (v.ACTUAL_LEVEL, 'Level'),
                (v.MIN_LEVEL, 'MinLevel'),
                (v.MAX_LEVEL, 'MaxLevel'),
                (v.PHYSICAL_MINIMUM, 'Ph.Min'),
                (v.POWER_ON_LEVEL, 'PowerOn'),
                (v.SYSTEM_FAILURE, 'FailLevel'),
                (v.SCENES, 'Scenes'),
            )],
            v.SWITCH: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.SWITCH_UP_ON, 'UpOn'),
                (v.SWITCH_UP_OFF, 'UpOff'),
                (v.SWITCH_DOWN_ON, 'DownOn'),
                (v.SWITCH_DOWN_OFF, 'DownOff'),
                (v.VIRTUAL_LEVEL, 'V.Level'),
            )],
            v.COLOUR: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.CC_COOLEST, 'Coolest'),
                (v.CC_WARMEST, 'Warmest'),
                (v.CC_PH_COOLEST, 'Ph.Coolest'),
                (v.CC_PH_WARMEST, 'Ph.Warmest'),
                (v.CC_COLOR_TEMPERATURE, 'Temperature'),
            )],
            v.DALI2: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.IS_ENABLED, 'Enabled'),
                (v.EVENT_SCHEME, 'EventScheme'),
                (v.EVENT_FILTER, 'EventFilter'),
                (v.INSTANCE_GROUP_0, 'Group0'),
                (v.INSTANCE_GROUP_1, 'Group1'),
                (v.INSTANCE_GROUP_2, 'Group2'),
                (v.EVENT_PRIORITY, 'Priority'),
                (v.RESOLUTION, 'Res.'),
                (v.FEATURE_TYPES, 'Features'),
            )],
            v.SENSORS: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.DEAD_TIME, 'DeadTime'),
                (v.REPORT_TIME, 'ReportTime'),
                (v.HYSTERESIS, 'Hysteresis'),
                (v.HYSTERESIS_MIN, 'Hys.Min'),
                (v.CATCHING, 'Catching'),
                (v.HOLD_TIME, 'HoldTime'),
            )],
            v.BUTTONS: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.SHORT_TIME, 'ShortTime'),
                (v.SHORT_TIME_MIN, 'ShortMin'),
                (v.DOUBLE_TIME, 'DoubleTime'),
                (v.DOUBLE_TIME_MIN, 'DoubleMin'),
                (v.REPEAT_TIME, 'RepeatTime'),
                (v.STUCK_TIME, 'StuckTime'),
            )],
        }

    @classmethod
    def commands(cls):
        return {
            v.COMMON: [
                dict(name=name, verbose=verb, input=cls.get_input(name, verb)) for name, verb in
                (
                    (dali1.reset.__name__, 'Reset'),
                    (dali1.identify.__name__, 'Identify'),
                )],
            v.DALI: [
                dict(name=name, verbose=verb, input=cls.get_input(name, verb)) for name, verb in
                (
                    (dali1.discovery.__name__, 'Discovery'),
                    (dali1.off.__name__, 'Off'),
                    (dali1.up.__name__, 'Up'),
                    (dali1.down.__name__, 'Down'),
                    (dali1.step_up.__name__, 'StepUp'),
                    (dali1.step_down.__name__, 'StepDown'),
                    (dali1.recall_min_level.__name__, 'MinLevel'),
                    (dali1.recall_max_level.__name__, 'MaxLevel'),
                    (dali1.step_down_and_off.__name__, 'StepDownOff'),
                    (dali1.on_and_step_up.__name__, 'OnStepUp'),
                    (dali1.go_to_last_active_level.__name__, 'LastLevel'),
                )],
        }

    @classmethod
    def get_input(cls, name, verbose=None):
        return None
        # res = None
        if name == v.ADDRESS:
            res = fields.ChoiceField.of_range(0, 63, (255, 'MASK'))

        elif name == v.FADE_TIME:
            res = fields.ChoiceField.of_fade_time()

        elif name == v.FADE_RATE:
            res = fields.ChoiceField.of_fade_rate()

        elif name == v.DIMMING_CURVE:
            res = fields.ChoiceField.of_dimming_curve()

        elif name in (v.ACTUAL_LEVEL, v.MIN_LEVEL, v.MAX_LEVEL, v.POWER_ON_LEVEL, v.SYSTEM_FAILURE,
                      v.HYSTERESIS_MIN, v.SWITCH_UP_ON, v.SWITCH_UP_OFF, v.SWITCH_DOWN_ON, v.SWITCH_DOWN_OFF):
            res = fields.ChoiceField.of_range(0, 255)

        elif name in (v.CC_COOLEST, v.CC_WARMEST, v.CC_COLOR_TEMPERATURE):
            res = fields.IntegerField.of_range(1, 65535)

        elif name == v.HYSTERESIS:
            res = fields.ChoiceField.of_range(0, 25)

        elif name == v.EVENT_PRIORITY:
            res = fields.ChoiceField.of_event_priority()

        elif name == v.EVENT_SCHEME:
            res = fields.ChoiceField.of_event_scheme()

        elif name == v.EVENT_FILTER:
            res = fields.ChoiceField.of_event_filter()

        elif name == v.OPERATING_MODE:
            res = fields.ChoiceField.of_operating_mode()

        elif name == v.INSTANCE_GROUP_0 or name == v.INSTANCE_GROUP_1 or name == v.INSTANCE_GROUP_2:
            res = fields.ChoiceField.of_instance_group()

        elif name in (v.IDENTIFY, v.DISCOVERY, v.IS_ENABLED):
            res = fields.ChoiceField.of_boolean()

        elif name == v.HOLD_TIME:
            res = fields.ChoiceField.of_hold_time()

        elif name == v.DEAD_TIME:
            res = fields.ChoiceField.of_dead_time()

        elif name == v.REPORT_TIME:
            res = fields.ChoiceField.of_report_time()

        elif name == v.SHORT_TIME_MIN or name == v.SHORT_TIME:
            res = fields.ChoiceField.of_short_time()

        elif name == v.DOUBLE_TIME:
            res = fields.ChoiceField.of_double_time()

        elif name == v.DOUBLE_TIME_MIN:
            res = fields.ChoiceField.of_double_time_min()

        elif name == v.REPEAT_TIME:
            res = fields.ChoiceField.of_repeat_time()

        elif name == v.STUCK_TIME:
            res = fields.ChoiceField.of_stuck_time()

        elif name == v.GROUPS or name == v.SCENES:
            return forms.TextInput(attrs=dict(
                style='width: 50px; display: none;',
                readonly=True,
                onchange='onChange(this)'
            )).render(name=name, value='')

        elif verbose is not None:
            return mark_safe(
                '<input type="submit" name="%s" value="%s" onclick="sendCommand(this);">' % (name, verbose)
            )

        if res:
            return res.widget.render(name=name, value='', attrs={'onchange': 'onChange(this)'})
        else:
            return forms.TextInput(attrs={
                'style': 'width: 50px; display: none;',
                'class': 'field-value-read-only'
            }).render(name=name, value='')

==> resh-5.1.0.9-py3-none-any.whl: reface/dashboard/forms.py <==
from django.utils.translation import gettext_lazy as _
from django import forms
from django.utils.safestring import mark_safe

from reface.dashboard import fields
from resh.domains import dali1, dali2
from resh.utils import const_values as v


class _LineUtils(forms.Form):
    DALI1 = 'dali'
    DALI2 = 'dali2'
    ALL = 'all'

    ACTION = 'action'
    START = 'start'
    STOP = 'stop'
    SCAN = 'scan'

    EXTEND = 'extend_line'
    CONSTRUCT = 'construct_line'
    DOUBLE_ADDRESSES = 'fix_double_addresses'

    VERBOSE_EXTEND = _('Extend line')
    VERBOSE_CONSTRUCT = _('Construct line')
    VERBOSE_DOUBLE_ADDRESSES = _('Fix double addresses')

    COMMANDS = {
        DALI1: {
            EXTEND: dali1.extend_line,
            CONSTRUCT: dali1.construct_line,
            DOUBLE_ADDRESSES: dali1.fix_double_addresses,
            SCAN: dali1.dump,
        },
        DALI2: {
            EXTEND: dali2.extend_line,
            CONSTRUCT: dali2.construct_line,
            DOUBLE_ADDRESSES: dali2.fix_double_addresses,
            SCAN: dali2.dump,
        }
    }

    DALI_TYPES = (('', ''), (DALI1, 'DALI 1'), (DALI2, 'DALI 2'))


class LineBuilder(_LineUtils):
    dali_type = forms.ChoiceField(choices=_LineUtils.DALI_TYPES, label=_('Device types'))
    cross = forms.BooleanField(initial=True, required=False, label=_('Cross addresses'))
    first_address = forms.IntegerField(initial=0, min_value=0, max_value=64, label=_('Start from'))

    @classmethod
    def verbose_name(cls, command_name):
        return {
            cls.EXTEND: cls.VERBOSE_EXTEND,
            cls.CONSTRUCT: cls.VERBOSE_CONSTRUCT,
            cls.DOUBLE_ADDRESSES: cls.VERBOSE_DOUBLE_ADDRESSES,
        }.get(command_name, _('Device addressing'))

    @property
    def mode(self): return 'CROSS' if self.cleaned_data['cross'] else 'NOCROSS'

    def command(self, action): return self.COMMANDS[self.cleaned_data['dali_type']][action]

    @property
    def start_address(self): return self.cleaned_data.get('first_address', 0)


class LineScanner(_LineUtils):
    @classmethod
    def columns(cls):
        return {
            v.COMMON: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.GTIN, 'Gtin'),
                (v.SERIAL, 'Serial'),
                (v.GTIN_OEM, 'GtinOem'),
                (v.SERIAL_OEM, 'SerialOem'),
                (v.FIRMWARE, 'F.Ver'),
                (v.HARDWARE, 'H.Ver'),
                (v.GROUPS, 'Groups'),
                (v.OPERATING_MODE, 'Op.Mode'),
            )],
            v.DALI: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.FADE_TIME, 'FadeTime'),
                (v.FADE_RATE, 'FadeRate'),
                (v.DIMMING_CURVE, 'DimmingCurve'),
                (v.ACTUAL_LEVEL, 'Level'),
                (v.MIN_LEVEL, 'MinLevel'),
                (v.MAX_LEVEL, 'MaxLevel'),
                (v.PHYSICAL_MINIMUM, 'Ph.Min'),
                (v.POWER_ON_LEVEL, 'PowerOn'),
                (v.SYSTEM_FAILURE, 'FailLevel'),
                (v.SCENES, 'Scenes'),
            )],
            v.SWITCH: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.SWITCH_UP_ON, 'UpOn'),
                (v.SWITCH_UP_OFF, 'UpOff'),
                (v.SWITCH_DOWN_ON, 'DownOn'),
                (v.SWITCH_DOWN_OFF, 'DownOff'),
                (v.VIRTUAL_LEVEL, 'V.Level'),
            )],
            v.COLOUR: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.CC_COOLEST, 'Coolest'),
                (v.CC_WARMEST, 'Warmest'),
                (v.CC_PH_COOLEST, 'Ph.Coolest'),
                (v.CC_PH_WARMEST, 'Ph.Warmest'),
                (v.CC_COLOR_TEMPERATURE, 'Temperature'),
            )],
            v.DALI2: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.IS_ENABLED, 'Enabled'),
                (v.EVENT_SCHEME, 'EventScheme'),
                (v.EVENT_FILTER, 'EventFilter'),
                (v.INSTANCE_GROUP_0, 'Group0'),
                (v.INSTANCE_GROUP_1, 'Group1'),
                (v.INSTANCE_GROUP_2, 'Group2'),
                (v.EVENT_PRIORITY, 'Priority'),
                (v.RESOLUTION, 'Res.'),
                (v.FEATURE_TYPES, 'Features'),
            )],
            v.SENSORS: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.DEAD_TIME, 'DeadTime'),
                (v.REPORT_TIME, 'ReportTime'),
                (v.HYSTERESIS, 'Hysteresis'),
                (v.HYSTERESIS_MIN, 'Hys.Min'),
                (v.CATCHING, 'Catching'),
                (v.HOLD_TIME, 'HoldTime'),
            )],
            v.BUTTONS: [dict(name=name, verbose=verb, input=cls.get_input(name)) for name, verb in (
                (v.SHORT_TIME, 'ShortTime'),
                (v.SHORT_TIME_MIN, 'ShortMin'),
                (v.DOUBLE_TIME, 'DoubleTime'),
                (v.DOUBLE_TIME_MIN, 'DoubleMin'),
                (v.REPEAT_TIME, 'RepeatTime'),
                (v.STUCK_TIME, 'StuckTime'),
            )],
        }

    @classmethod
    def commands(cls):
        return {
            v.COMMON: [
                dict(name=name, verbose=verb, input=cls.get_input(name, verb)) for name, verb in
                (
                    (dali1.reset.__name__, 'Reset'),
                    (dali1.identify.__name__, 'Identify'),
                )],
            v.DALI: [
                dict(name=name, verbose=verb, input=cls.get_input(name, verb)) for name, verb in
                (
                    (dali1.discovery.__name__, 'Discovery'),
                    (dali1.off.__name__, 'Off'),
                    (dali1.up.__name__, 'Up'),
                    (dali1.down.__name__, 'Down'),
                    (dali1.step_up.__name__, 'StepUp'),
                    (dali1.step_down.__name__, 'StepDown'),
                    (dali1.recall_min_level.__name__, 'MinLevel'),
                    (dali1.recall_max_level.__name__, 'MaxLevel'),
                    (dali1.step_down_and_off.__name__, 'StepDownOff'),
                    (dali1.on_and_step_up.__name__, 'OnStepUp'),
                    (dali1.go_to_last_active_level.__name__, 'LastLevel'),
                )],
        }

    @classmethod
    def get_input(cls, name, verbose=None):
        return None
        # res = None
        if name == v.ADDRESS:
            res = fields.ChoiceField.of_range(0, 63, (255, 'MASK'))

        elif name == v.FADE_TIME:
            res = fields.ChoiceField.of_fade_time()

        elif name == v.FADE_RATE:
            res = fields.ChoiceField.of_fade_rate()

        elif name == v.DIMMING_CURVE:
            res = fields.ChoiceField.of_dimming_curve()

        elif name in (v.ACTUAL_LEVEL, v.MIN_LEVEL, v.MAX_LEVEL, v.POWER_ON_LEVEL, v.SYSTEM_FAILURE,
                      v.HYSTERESIS_MIN, v.SWITCH_UP_ON, v.SWITCH_UP_OFF, v.SWITCH_DOWN_ON, v.SWITCH_DOWN_OFF):
            res = fields.ChoiceField.of_range(0, 255)

        elif name in (v.CC_COOLEST, v.CC_WARMEST, v.CC_COLOR_TEMPERATURE):
            res = fields.IntegerField.of_range(1, 65535)

        elif name == v.HYSTERESIS:
            res = fields.ChoiceField.of_range(0, 25)

        elif name == v.EVENT_PRIORITY:
            res = fields.ChoiceField.of_event_priority()

        elif name == v.EVENT_SCHEME:
            res = fields.ChoiceField.of_event_scheme()

        elif name == v.EVENT_FILTER:
            res = fields.ChoiceField.of_event_filter()

        elif name == v.OPERATING_MODE:
            res = fields.ChoiceField.of_operating_mode()

        elif name == v.INSTANCE_GROUP_0 or name == v.INSTANCE_GROUP_1 or name == v.INSTANCE_GROUP_2:
            res = fields.ChoiceField.of_instance_group()

        elif name in (v.IDENTIFY, v.DISCOVERY, v.IS_ENABLED):
            res = fields.ChoiceField.of_boolean()

        elif name == v.HOLD_TIME:
            res = fields.ChoiceField.of_hold_time()

        elif name == v.DEAD_TIME:
            res = fields.ChoiceField.of_dead_time()

        elif name == v.REPORT_TIME:
            res = fields.ChoiceField.of_report_time()

        elif name == v.SHORT_TIME_MIN or name == v.SHORT_TIME:
            res = fields.ChoiceField.of_short_time()

        elif name == v.DOUBLE_TIME:
            res = fields.ChoiceField.of_double_time()

        elif name == v.DOUBLE_TIME_MIN:
            res = fields.ChoiceField.of_double_time_min()

        elif name == v.REPEAT_TIME:
            res = fields.ChoiceField.of_repeat_time()

        elif name == v.STUCK_TIME:
            res = fields.ChoiceField.of_stuck_time()

        elif name == v.GROUPS or name == v.SCENES:
            return forms.TextInput(attrs=dict(
                style='width: 50px; display: none;',
                readonly=True,
                onchange='onChange(this)'
            )).render(name=name, value='')

        elif verbose is not None:
            return mark_safe(
                '<input type="submit" name="%s" value="%s" onclick="sendCommand(this);">' % (name, verbose)
            )

        if res:
            return res.widget.render(name=name, value='', attrs={'onchange': 'onChange(this)'})
        else:
            return forms.TextInput(attrs={
                'style': 'width: 50px; display: none;',
                'class': 'field-value-read-only'
            }).render(name=name, value='')
